@@ -20,7 +20,20 @@
  *
  */
 
+#ifndef __CONNMANCTL_COMMANDS_H
+#define __CONNMANCTL_COMMANDS_H
+
 #include <dbus/dbus.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int __connmanctl_commands(DBusConnection *connection, char *argv[], int argc);
 char *__connmanctl_lookup_command(const char *text, int state);
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif /* __CONNMANCTL_COMMANDS_H */
